<template>
  <Popup ref="pop" :title="title" left="calc(100% - 330px)">
    <div class="shadowAnalysis">
      <el-form ref="form" :model="form" :rules="rules" label-width="105px">
        <el-form-item prop="data" label="日期选择">
          <el-date-picker
            v-model="form.date"
            type="date"
            placeholder="选择日期"
            value-format="yyyy-MM-dd"
            @change="handleChange"
          >
          </el-date-picker>
        </el-form-item>
        <el-form-item prop="startTime" label="开始时间">
          <el-time-select
            v-model="form.startTime"
            :picker-options="{
              start: '00:00',
              step: '00:15',
              end: '23:45',
            }"
            placeholder="开始时间"
            @change="handleChange"
          >
          </el-time-select>
        </el-form-item>
        <el-form-item prop="endTime" label="结束时间">
          <el-time-select
            :picker-options="{
              start: '00:00',
              step: '00:15',
              end: '23:45',
            }"
            v-model="form.endTime"
            placeholder="结束时间"
            @change="handleChange"
          >
          </el-time-select>
        </el-form-item>
        <el-form-item prop="playTime" label="播放时间">
          <el-input
            v-model.number="form.playTime"
            @change="handleChange"
          ></el-input>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" @click="submitForm('form')">
            播放
          </el-button>
          <el-button type="primary" @click="pause"> 暂停 </el-button>
        </el-form-item>
      </el-form>
    </div>
  </Popup>
</template>

<script>
import Popup from "@tools/Popup.vue";
export default {
  name: "shadowAnalysis",
  components: {
    Popup,
  },
  data() {
    var checkEndTime = (rule, value, callback) => {
      if (value < this.form.startTime) {
        callback(new Error("结束时间小于开始时间"));
      } else {
        callback();
      }
    };
    var checkNumber = (rule, value, callback) => {
      if (!Number.isInteger(value)) {
        callback(new Error("请输入数字值"));
      } else {
        callback();
      }
    };
    return {
      isStop: true,
      isPlay: false,
      title: "阴影分析",
      form: {
        date: "2021-12-01",
        startTime: "06:00",
        endTime: "10:00",
        playTime: 3,
      },
      rules: {
        date: [{ required: true, message: "请选择日期", trigger: "change" }],
        startTime: [
          { required: true, message: "请选择开始时间", trigger: "change" },
        ],
        endTime: [
          {
            required: true,
            validator: checkEndTime,
            trigger: "blur",
          },
        ],
        playTime: [
          {
            required: true,
            validator: checkNumber,
            trigger: "blur",
          },
        ],
      },
    };
  },
  methods: {
    handleChange() {
      this.isPlay = false;
      this.isStop = true;
      window.Viewer.shadows = false;
    },
    open() {
      this.$refs.pop.open();
    },
    close() {
      this.$refs.pop.close();
      window.Viewer.shadows = false;
      this.isPlay = false;
      this.isStop = true;
    },
    submitForm(formName) {
      this.$refs[formName].validate((valid) => {
        if (valid) {
          if (this.isStop) {
            if (this.isPlay) {
              sgworld.Command.execute(3, 3);
            } else {
              window.Viewer.shadows = true;
              this.isStop = false;
              var startTime = new Date(
                this.form.date + " " + this.form.startTime
              );
              Viewer.clock.startTime = Cesium.JulianDate.fromDate(startTime);
              Viewer.clock.currentTime = Cesium.JulianDate.fromDate(startTime);
              var endTime = new Date(this.form.date + " " + this.form.endTime);
              Viewer.clock.stopTime = Cesium.JulianDate.fromDate(endTime);
              var speed =
                (endTime.getTime() / 1000 - startTime.getTime() / 1000) /
                this.form.playTime;
              Viewer.clock.multiplier = speed;
            }
          }
        } else {
          console.log("error submit!!");
          return false;
        }
      });
    },
    pause() {
      this.isStop = true;
      this.isPlay = true;
      window.sgworld.Command.execute(3, 5);
    },
  },
};
</script>

<style scoped>
.shadowAnalysis {
  margin-top: 20px;
}
.el-input {
  width: 180px !important;
}
.demonstration {
  color: white;
}
.el-button {
  width: 61px;
}
</style>